%% Ellipsometry example
% This simple driver directly starts the simulation

%% Parameter
n_super = 1.0; % refractive index in incident domain
n_SiO2=1.5+0.0002i;    % refractive index in thin film
n_sub = 3.5;   % refractive index in substrate
thetas = [0 20];   % range of incidence angles
lambda_scan = [200 1000];  % range of incidence wavelengths

n = [n_super,n_SiO2, n_sub]';

d = 50e-9;

%% run simulation
keys.layer_thickness = d;
keys.eps_rel_matrix = n.^2;
keys.lambda_start = lambda_scan(1)*1e-9;
keys.delta_lambda = 0.5*1e-9;
keys.lambda_end = lambda_scan(2)*1e-9;
keys.theta_start = thetas(1);
keys.delta_theta = 2;
keys.theta_end= thetas(2);
results = jcmwave_solve('project.jcmp',keys);

%% plot result
solution = results{1};
lambda_plot = solution.Lambda0/1e-9;

Rs = abs(solution.Rs{end}).^2;
Rp = abs(solution.Rp{end}).^2;

rho= solution.Rp{end}./solution.Rs{end};
delta = angle(rho);

figure()
plot(lambda_plot,Rs,'b-',...
    lambda_plot,Rp,'b--',...
lambda_plot,delta,'r-')
legend('Rs','Rp','delta')
xlabel('lambda [nm]')
ylabel('R / delta ')
title('thin film reflectance')