import sys
import os
try:
    sys.path.append(os.path.join(os.getenv('JCMROOT'), 'ThirdPartySupport', 'Python'))
except:
    pass

import jcmwave

import numpy as np
import matplotlib.pyplot as plt

# Parameters
n_super = 1.0  # Refractive index in incident domain
n_SiO2 = 1.5+0.0002j       # Refractive index in thin film
n_sub = 3.5    # Refractive index in substrate

theta = [0, 20] # Range of incidence angles
lambda_scan = [200., 1000.]   # Range of incidence wavelengths

# Setup DBR
n = np.zeros(3,dtype=np.complex128)
n[0] = n_super
n[1] = n_SiO2
n[2] = n_sub


d = 50e-9;

# Run simulation
# Layered media solver requires matrix input for permittivity
# number of columns must be len(d)+2
keys = {
    'layer_thickness': d,
    'eps_rel_matrix': np.atleast_2d(n**2).T,
    'lambda_start': lambda_scan[0]*1e-9,
    'delta_lambda': 0.5*1e-9,
    'lambda_end': lambda_scan[-1]*1e-9,
    'theta_start': theta[0],
    'delta_theta': 2.,
    'theta_end': theta[1]
}

results = jcmwave.solve('project.jcmp', keys)

# Plot result
solution = results[0]
lambda_plot = solution['Lambda0'].real / 1e-9
Rs = np.abs(solution['Rs'][9])**2
Rp = np.abs(solution['Rp'][9])**2
rho = solution['Rp'][9]/solution['Rs'][9]
delta=np.angle(rho)

plt.figure()
plt.plot(lambda_plot, Rs, 'b-', label='Rs')
plt.plot(lambda_plot, Rp, 'b--', label='Rp')
plt.plot(lambda_plot, delta, 'r-', label='delta')
plt.legend()
plt.xlabel('lambda [nm]')
plt.ylabel('R / delta')
plt.title('thin film reflectance')
plt.show()
