%% Distributed Bragg Reflector (DBR) example
% This simple driver directly starts the simulation

%% Parameter
n_super = 1.0; % refractive index in incident domain
n1=2.6;        % refractive index in Bragg mirror
n2=1.5;        % refractive index in Bragg mirror
n_sub = 1.5;   % refractive index in substrate
nDBR = 20;     % # of DBR pairs (repetition of n1/n2 pairs)
lambda_design = 1000e-9;   % design vacuum wavelength 1000nm for DBR
theta = 20:2:30;   % range of incidence angles
lambda_scan = 0.6* lambda_design : .5e-9: 2*lambda_design;  % range of incidence wavelengths

%% setup DBR
n = zeros(2*nDBR+2,1);
n(1)=n_super;
n(2:2:end) =n1; 
n(3:2:end) =n2; 
n(end) = n_sub;

% lambda/4 layers
d = lambda_design./(4*n(2:end-1));

%% run simulation
keys.layer_thickness = d;
keys.eps_rel_matrix = n.^2;
keys.lambda_scan = lambda_scan;
keys.thetas = theta;
results = jcmwave_solve('project.jcmp',keys);


%% plot result
solution = results{1};
lambda_plot = solution.Lambda0/1e-9;
Rs = abs(solution.Rs{1}).^2;
Rp = abs(solution.Rp{1}).^2;

figure()
plot(lambda_plot,Rs,'b-',...
lambda_plot,Rp,'r-')
legend('Rs','Rp')
xlabel('lambda [nm]')
ylabel('R ')
ylim([0.0,1.05])
title(sprintf('DBR reflectivity (%d pairs, %d deg)',nDBR, theta(1)))