import sys
import os
try:
    sys.path.append(os.path.join(os.getenv('JCMROOT'), 'ThirdPartySupport', 'Python'))
except:
    pass

import jcmwave

import numpy as np
import matplotlib.pyplot as plt

# Parameters
n_super = 1.0  # Refractive index in incident domain
n1 = 2.6       # Refractive index in Bragg mirror
n2 = 1.5       # Refractive index in Bragg mirror
n_sub = 1.5    # Refractive index in substrate
nDBR = 20      # Number of DBR pairs (repetition of n1/n2 pairs)
lambda_design = 1000e-9  # Design vacuum wavelength 1000nm for DBR
theta = np.arange(20, 32, 2)  # Range of incidence angles
lambda_scan = np.arange(0.6 * lambda_design, 2 * lambda_design, 0.5e-9)  # Range of incidence wavelengths

# Setup DBR
n = np.zeros(2 * nDBR + 2)
n[0] = n_super
n[1::2] = n1
n[2::2] = n2
n[-1] = n_sub

# Lambda/4 layers
d = lambda_design / (4 * n[1:-1])

# Run simulation
# Layered media solver requires matrix input for permittivity
# number of columns must be len(d)+2
keys = {
    'layer_thickness': d,
    'eps_rel_matrix': np.atleast_2d(n**2).T,
    'lambda_scan': lambda_scan,
    'thetas': theta
}

results = jcmwave.solve('project.jcmp', keys)

# Plot result
solution = results[0]
lambda_plot = solution['Lambda0'] / 1e-9
Rs = np.abs(solution['Rs'][0])**2
Rp = np.abs(solution['Rp'][0])**2

plt.figure()
plt.plot(lambda_plot, Rs, 'b-', label='Rs')
plt.plot(lambda_plot, Rp, 'r-', label='Rp')
plt.legend()
plt.xlabel('lambda [nm]')
plt.ylabel('R')
plt.ylim([0.0, 1.05])
plt.title(f'DBR reflectivity ({nDBR} pairs, {theta[0]} deg)')
plt.show()